#if defined(RENESAS_SIMULATOR_DEBUGGING)

#include "platform.h"

#define VEDIAGRAM_BUTTON_AUTORECOVERY_TIME 2 /* calls of RenesasRXSimDebugIntEmulation() */

void RenesasRXSimDebugIntEmulation(void)
{
/* The check such as 'get_ipl() < IPR(ICU, IRQ4)' or 'get_ipl() < IPR(SCI1, TXI1 or RXI1 etc)'
 * or '0 != (get_psw() & 0x00010000)' does not work well because this function is called
 * from TickHook from TickHandler from TickInterrupt i.e. here is the task critical section
 * and the multiple interrupt enabled state.
 */

#define ICU_IRQCR_IRQMD_LOW_LEVEL    0
#define ICU_IRQCR_IRQMD_FALLING_EDGE 1
#define ICU_IRQCR_IRQMD_RISING_EDGE  2
#define ICU_IRQCR_IRQMD_BOTH_EDGE    3

    /* IRQ4 */
    static uint8_t PORTB_PIDR_BIT_B1_prev = 0;
    static uint16_t PORTB_PIDR_BIT_B1_time = 0;
    static bool PORTB_PIDR_BIT_B1_trig = false;

    switch (ICU.IRQCR[4].BIT.IRQMD)
    {
    case ICU_IRQCR_IRQMD_LOW_LEVEL:
        if (0 == PORTB.PIDR.BIT.B1)
        {
            PORTB_PIDR_BIT_B1_trig = true;
        }
        break;
    case ICU_IRQCR_IRQMD_FALLING_EDGE:
        if (1 == PORTB_PIDR_BIT_B1_prev && 0 == PORTB.PIDR.BIT.B1)
        {
            PORTB_PIDR_BIT_B1_trig = true;
        }
        break;
    case ICU_IRQCR_IRQMD_RISING_EDGE:
        if (0 == PORTB_PIDR_BIT_B1_prev && 1 == PORTB.PIDR.BIT.B1)
        {
            PORTB_PIDR_BIT_B1_trig = true;
        }
        break;
    case ICU_IRQCR_IRQMD_BOTH_EDGE:
        if (PORTB_PIDR_BIT_B1_prev != PORTB.PIDR.BIT.B1)
        {
            PORTB_PIDR_BIT_B1_trig = true;
        }
        break;
    default: /* Never come here */
        break;
    }

    if (true == PORTB_PIDR_BIT_B1_trig && 0 != IEN(ICU, IRQ4))
    {
        int_exception( VECT(ICU, IRQ4) );
        PORTB_PIDR_BIT_B1_trig = false;
    }

    switch (ICU.IRQCR[4].BIT.IRQMD)
    {
    case ICU_IRQCR_IRQMD_LOW_LEVEL:
    case ICU_IRQCR_IRQMD_BOTH_EDGE:
        /* Keep the value of PORTB.PIDR.BIT.B1 */
        break;
    case ICU_IRQCR_IRQMD_FALLING_EDGE:
        /* Invert the value of PORTB.PIDR.BIT.B1 automatically */
        if (0 == PORTB.PIDR.BIT.B1)
        {
            if (VEDIAGRAM_BUTTON_AUTORECOVERY_TIME > PORTB_PIDR_BIT_B1_time)
            {
                PORTB_PIDR_BIT_B1_time++;
            }
            else if (VEDIAGRAM_BUTTON_AUTORECOVERY_TIME <= PORTB_PIDR_BIT_B1_time)
            {
                PORTB.PIDR.BIT.B1 = 1;
                PORTB_PIDR_BIT_B1_time = 0;
            }
        }
        break;
    case ICU_IRQCR_IRQMD_RISING_EDGE:
        /* Invert the value of PORTB.PIDR.BIT.B1 automatically */
        if (1 == PORTB.PIDR.BIT.B1)
        {
            if (VEDIAGRAM_BUTTON_AUTORECOVERY_TIME > PORTB_PIDR_BIT_B1_time)
            {
                PORTB_PIDR_BIT_B1_time++;
            }
            else if (VEDIAGRAM_BUTTON_AUTORECOVERY_TIME == PORTB_PIDR_BIT_B1_time)
            {
                PORTB.PIDR.BIT.B1 = 0;
                PORTB_PIDR_BIT_B1_time = 0;
            }
        }
        break;
    default: /* Never come here */
        break;
    }

    PORTB_PIDR_BIT_B1_prev = PORTB.PIDR.BIT.B1;

#define BSP_PRV_E1_DBG_PORT (*(volatile st_dbg_t     R_BSP_EVENACCESS_SFR *)0x84080)
#define BSP_PRV_TXFL0EN     (0x00000100)          /* debug tx flow control bit */
#define BSP_PRV_RXFL0EN     (0x00001000)          /* debug RX flow control bit */
typedef struct
{
    uint32_t   tx_data;     /* Debug Virtual Console TX data */
    char       wk1[12];     /* spacer */
    uint32_t   rx_data;     /* Debug Virtual Console RX data */
    char       wk2[44];     /* spacer */
    uint32_t   dbgstat;     /* Debug Virtual Console Status */
} st_dbg_t;

    /* SCI1 */
    while (0 == (BSP_PRV_E1_DBG_PORT.dbgstat & BSP_PRV_TXFL0EN))
    {
        if (0 != SCI1.SCR.BIT.TE && 0 != SCI1.SCR.BIT.TIE && 0 != IEN(SCI1, TXI1))
        {
            int_exception( VECT(SCI1, TXI1) );
            if (0 != SCI1.SCR.BIT.TIE)
            {
                BSP_PRV_E1_DBG_PORT.tx_data = (int32_t)SCI1.TDR;
            }
        }
        else
        {
            break;
        }
    }
    if (0 != SCI1.SCR.BIT.TE && 0 != SCI1.SCR.BIT.TEIE && 0 != IEN(ICU, GROUPBL0) && 0 != ICU.GENBL0.BIT.EN6)
    {
        ICU.GRPBL0.BIT.IS6 = 1;
        int_exception( VECT(ICU, GROUPBL0) );
        if(0 == SCI1.SCR.BIT.TE || 0 == SCI1.SCR.BIT.TEIE)
        {
            ICU.GRPBL0.BIT.IS6 = 0;
        }
    }
    while (0 != (BSP_PRV_E1_DBG_PORT.dbgstat & BSP_PRV_RXFL0EN))
    {
        if(0 != SCI1.SCR.BIT.RE && 0 != SCI1.SCR.BIT.RIE && 0 != IEN(SCI1, RXI1))
        {
            SCI1.RDR = (uint8_t)BSP_PRV_E1_DBG_PORT.rx_data;
            int_exception( VECT(SCI1, RXI1) );
        }
        else
        {
            break;
        }
    }
}

#endif

#if 0 /* Memo Memo Memo */

/* Switches */
#define SW1             (PORTB.PIDR.BIT.B1)

/* LED port settings */
#define LED0            (PORTD.PODR.BIT.B6)
#define LED1            (PORTD.PODR.BIT.B7)

#endif /* Memo Memo Memo */

#include "platform.h"

#undef ICU

#undef PORT0
#undef PORT1
#undef PORT2
#undef PORT3
#undef PORT4
#undef PORT5
#undef PORT6
#undef PORT7
#undef PORT8
#undef PORT9
#undef PORTA
#undef PORTB
#undef PORTC
#undef PORTD
#undef PORTE
#undef PORTF
#undef PORTG
#undef PORTJ

#undef SCI0
#undef SCI1
#undef SCI2
#undef SCI3
#undef SCI4
#undef SCI5
#undef SCI6
#undef SCI7
#undef SCI8
#undef SCI9
#undef SCI10
#undef SCI11
#undef SCI12

VOLATILE st_icu_t   * const ICU   = (st_icu_t   *)0x87000;

VOLATILE st_port0_t * const PORT0 = (st_port0_t *)0x8C000;
VOLATILE st_port1_t * const PORT1 = (st_port1_t *)0x8C001;
VOLATILE st_port2_t * const PORT2 = (st_port2_t *)0x8C002;
VOLATILE st_port3_t * const PORT3 = (st_port3_t *)0x8C003;
VOLATILE st_port4_t * const PORT4 = (st_port4_t *)0x8C004;
VOLATILE st_port5_t * const PORT5 = (st_port5_t *)0x8C005;
VOLATILE st_port6_t * const PORT6 = (st_port6_t *)0x8C006;
VOLATILE st_port7_t * const PORT7 = (st_port7_t *)0x8C007;
VOLATILE st_port8_t * const PORT8 = (st_port8_t *)0x8C008;
VOLATILE st_port9_t * const PORT9 = (st_port9_t *)0x8C009;
VOLATILE st_porta_t * const PORTA = (st_porta_t *)0x8C00A;
VOLATILE st_portb_t * const PORTB = (st_portb_t *)0x8C00B;
VOLATILE st_portc_t * const PORTC = (st_portc_t *)0x8C00C;
VOLATILE st_portd_t * const PORTD = (st_portd_t *)0x8C00D;
VOLATILE st_porte_t * const PORTE = (st_porte_t *)0x8C00E;
VOLATILE st_portf_t * const PORTF = (st_portf_t *)0x8C00F;
VOLATILE st_portg_t * const PORTG = (st_portg_t *)0x8C010;
VOLATILE st_portj_t * const PORTJ = (st_portj_t *)0x8C012;

VOLATILE st_sci0_t  * const SCI0  = (st_sci0_t  *)0x8A000;
VOLATILE st_sci0_t  * const SCI1  = (st_sci0_t  *)0x8A020;
VOLATILE st_sci0_t  * const SCI2  = (st_sci0_t  *)0x8A040;
VOLATILE st_sci0_t  * const SCI3  = (st_sci0_t  *)0x8A060;
VOLATILE st_sci0_t  * const SCI4  = (st_sci0_t  *)0x8A080;
VOLATILE st_sci0_t  * const SCI5  = (st_sci0_t  *)0x8A0A0;
VOLATILE st_sci0_t  * const SCI6  = (st_sci0_t  *)0x8A0C0;
VOLATILE st_sci0_t  * const SCI7  = (st_sci0_t  *)0x8A0E0;
VOLATILE st_sci0_t  * const SCI8  = (st_sci0_t  *)0x8A100;
VOLATILE st_sci0_t  * const SCI9  = (st_sci0_t  *)0x8A120;
VOLATILE st_sci10_t * const SCI10 = (st_sci10_t *)0xD0040;
VOLATILE st_sci10_t * const SCI11 = (st_sci10_t *)0xD0060;
VOLATILE st_sci12_t * const SCI12 = (st_sci12_t *)0x8B300;
